@@ -65,10 +65,16 @@ extern "C" {
 #define ERROR_TDNF_ERASE_NEEDS_INSTALL      1031
 #define ERROR_TDNF_OPERATION_ABORTED        1032
 
+// for invalid input on interactive questions
+#define ERROR_TDNF_INVALID_INPUT            1033
+
 //curl errors
-#define ERROR_TDNF_CURL_INIT                1200
-#define ERROR_TDNF_CURL_BASE                1201
-#define ERROR_TDNF_CURL_END                 1299
+#define ERROR_TDNF_CURL_INIT                  1200
+#define ERROR_TDNF_CURL_BASE                  1201
+#define ERROR_TDNF_CURLE_UNSUPPORTED_PROTOCOL 1202
+#define ERROR_TDNF_CURLE_FAILED_INIT          1203
+#define ERROR_TDNF_CURLE_URL_MALFORMAT        1204
+#define ERROR_TDNF_CURL_END                   1299
 
 #define ERROR_TDNF_SOLV_BASE                1300
 // general runtime error
@@ -134,6 +140,7 @@ extern "C" {
 #define ERROR_TDNF_PLUGIN_NO_MORE_EVENTS     1521
 #define ERROR_TDNF_NO_PLUGIN_ERROR           1522
 #define ERROR_TDNF_NO_GPGKEY_CONF_ENTRY      1523
+#define ERROR_TDNF_URL_INVALID               1524
 
 //RPM Transaction
 #define ERROR_TDNF_TRANS_INCOMPLETE     1525
@@ -160,6 +167,10 @@ extern "C" {
 #define ERROR_TDNF_BASEURL_DOES_NOT_EXISTS             2500
 #define ERROR_TDNF_CHECKSUM_VALIDATION_FAILED          2501
 #define ERROR_TDNF_METALINK_RESOURCE_VALIDATION_FAILED 2502
+
+//FIPS error
+#define ERROR_TDNF_FIPS_MODE_FORBIDDEN       2600
+
 #define CMD_INSTALL "install"
 
 #ifdef __cplusplus
